pub enum Range {
Unsigned(u32),
Signed(u32),
}Expand description
What the dividend is known to hold.
Variants
Unsigned(u32)
Something from zero up to, but not including, two to the power of this.
Signed(u32)
Something a signed integer of this many bits holds.