pub struct Program {
pub width: u32,
pub steps: Vec<Step>,
}Expand description
A rewrite, in the order it is written.
Fields
width: u32The width of the dividend and of the answer.
steps: Vec<Step>The steps, the last of which is the answer.