Written

Enum Written 

pub enum Written {
    Template,
    Goto,
    Operand,
}
What about an asm statement is not built yet.

Variants



Template

A template with instructions in it.



Goto

An asm goto, whose labels make the statement a terminator.



Operand

An operand this cannot put where the constraint says it goes.

Implementations

Source

impl Written

pub fn why(self) -> &'static str

The rest of the sentence that starts with the statement.