jumps

Function jumps 

pub fn jumps(
    func: &mut Func,
    tails: &[Tail],
    insts: &FrameInsts,
    names: &mut Interner,
) -> usize
Turns each Tail that can be into the epilogue and a jump, and says how many it turned.

Nothing happens on a machine with no jump to a name, which is what FrameInsts::away says.