Terms

Struct Terms 

pub struct Terms<'a> { /* private fields */ }
One instruction of a function, as the terms a rule could match.

Implementations

Source

impl<'a> Terms<'a>

pub fn new(func: &'a Func, root: Inst, plan: Plan) -> Self

The instruction, shown the way the plan says.

pub fn root(&self) -> Inst

The instruction this is about.

pub fn name(&self, inst: Inst) -> Option<&'static str>

What the root, or an instruction one of its operands was expanded into, is called in a rule file.

pub fn constant(&self, value: Value) -> Option<i128>

What a value is, if it is a constant.