of

Function of 

pub fn of(
    func: &Func,
    before: &[Inst],
    allocation: &Allocation,
    frame: &Frame,
) -> Vec<Kept>
Which declaration is where, over which instructions, or nothing at all for a function the answer cannot be given about. See the module documentation for which those are.