refusal

Function refusal 

pub fn refusal(
    func: &Func,
    names: &Interner,
    elsewhere: &Elsewhere,
) -> Option<&'static str>
Why no call in this function can be made in tail position, or None when one can.